value_KiB

Function value_KiB 

pub fn value_KiB(key: &str) -> Result<usize, ProcStatusError>
get the value of an entry by name if it is a size in KiB.

If you want to read several entries and you want them to be consistent, you should read the whole ProcStatus and call the value_KiB function on that instance. This would also be more efficient.